ScriptsRegistry class

A class that holds scripts and provides utilities to work with them.

Constructors

ScriptsRegistry(JsonMap scriptsMap)
Constructs a ScriptsRegistry from a JsonMap.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDefinition(String scriptString) → Definition
Get a serialized Definition for a script string if it exists. This function will throw errors if the script is not defined or if the script is not valid.
getPaths() → List<String>
Returns all valid paths to access values from the scripts map.
getReference(String scriptString) → Reference
Compute Reference parts from a script string.
lookup(String path) → dynamic
Searches for a given path in the scripts map.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runScript(String script, {String extra = ''}) → Future<int>
Runs a script from the scripts map if it exists.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

paths ↔ List<String>?
A list of all possible paths, used as a mean of memoization.
getter/setter pair
references ↔ Map<String, Reference>
Previously constructed references, used as a mean of memoization.
getter/setter pair
scripts ↔ JsonMap?
A map of scripts retrieved from pubspec.yaml.
getter/setter pair
searchResults ↔ Map<String, dynamic>
Previous search results, used as a mean of memoization.
getter/setter pair
serializedDefinitions ↔ Map<String, Definition>
Previously serialized definitions, used as a mean of memoization.
getter/setter pair